==========
searcheval
==========

Library implementing metrics and tools for the evaluation of search results (rankings).


Tests
=====

Testing requires having the nose library (`pip install nose`).
After installation, the package can be tested by executing from
outside the source directory::

    nosetests --exe -v
